Index: wp-includes/taxonomy.php
===================================================================
--- wp-includes/taxonomy.php	(revision 31151)
+++ wp-includes/taxonomy.php	(working copy)
@@ -1557,8 +1557,9 @@
  *
  *     @type string   $orderby               Field(s) to order terms by. Accepts term fields ('name', 'slug',
  *                                           'term_group', 'term_id', 'id'), 'count' for term taxonomy count,
  *                                           'include' to match the 'order' of the $include param, or 'none'
  *                                           to skip ORDER BY. Defaults to 'name'.
  *     @type string   $order                 Whether to order terms in ascending or descending order.
  *                                           Accepts 'ASC' (ascending) or 'DESC' (descending).
  *                                           Default 'ASC'.
@@ -1698,6 +1699,8 @@
 	$_orderby = strtolower( $args['orderby'] );
 	if ( 'count' == $_orderby ) {
 		$orderby = 'tt.count';
+	} elseif ( 'description' == $_orderby ) {
+		$orderby = 'tt.description';
 	} elseif ( 'name' == $_orderby ) {
 		$orderby = 't.name';
 	} elseif ( 'slug' == $_orderby ) {
@@ -1557,8 +1557,9 @@
  *     @type string   $orderby               Field(s) to order terms by. Accepts term fields ('name', 'slug',
  *                                           'term_group', 'term_id', 'id'), 'count' for term taxonomy count,
- *                                           'include' to match the 'order' of the $include param, or 'none'
- *                                           to skip ORDER BY. Defaults to 'name'.
+ *                                           'description' for term taxonomy description, 'include' to match
+ *                                           the 'order' of the $include param, or 'none' to skip ORDER BY.
+ *                                           Defaults to 'name'.
  *     @type string   $order                 Whether to order terms in ascending or descending order.
  *                                           Accepts 'ASC' (ascending) or 'DESC' (descending).
